@@ -542,6 +542,7 @@ static int execAppInternal(const char *appPath, const char *const *args, std::st
         // get return code
         int childReturnCode;
         waitpid(child, &childReturnCode, 0);
+        waitpid(-child, nullptr, 0);
         return childReturnCode;
     } else {
         // child process
@@ -553,6 +554,12 @@ static int execAppInternal(const char *appPath, const char *const *args, std::st
         close(readCerrPipe);
         close(writeCerrPipe);
 
+        // -> create process group
+        if (setpgid(0, 0)) {
+            cerr << Phrases::Error << "Unable create process group: " << std::strerror(errno) << Phrases::EndFlush;
+            exit(EXIT_FAILURE);
+        }
+
         // -> modify environment variable LLVM_PROFILE_FILE to apply new path for profiling output
         if (!newProfilingPath.empty()) {
             setenv("LLVM_PROFILE_FILE", newProfilingPath.data(), true);
@@ -561,12 +568,11 @@ static int execAppInternal(const char *appPath, const char *const *args, std::st
         // -> execute application
         if (enableSearchPath) {
             execvp(appPath, const_cast<char *const *>(args));
-
         } else {
             execv(appPath, const_cast<char *const *>(args));
         }
-        cerr << Phrases::Error << "Unable to execute \"" << appPath << "\": execv() failed" << Phrases::EndFlush;
-        exit(-101);
+        cerr << Phrases::Error << "Unable to execute \"" << appPath << "\": " << std::strerror(errno) << Phrases::EndFlush;
+        exit(EXIT_FAILURE);
     }
 
 #else
@@ -580,7 +586,6 @@ static int execAppInternal(const char *appPath, const char *const *args, std::st
  * \throws Throws std::runtime_error when the application can not be executed.
  * \remarks
  *  - The specified \a args must be 0 terminated. The first argument is the application name.
- *  - Currently only supported under UNIX.
  *  - \a stdout and \a stderr are cleared before.
  */
 int TestApplication::execApp(const char *const *args, string &output, string &errors, bool suppressLogging, int timeout) const
@@ -640,7 +645,6 @@ int TestApplication::execApp(const char *const *args, string &output, string &er
  * \remarks
  * - Intended to invoke helper applications (eg. to setup test files). Use execApp() and TestApplication::execApp() to
  *   invoke the application to be tested itself.
- * - Currently only supported under UNIX.
  */
 int execHelperApp(const char *appPath, const char *const *args, std::string &output, std::string &errors, bool suppressLogging, int timeout)
 {
@@ -655,7 +659,6 @@ int execHelperApp(const char *appPath, const char *const *args, std::string &out
  * \remarks
  * - Intended to invoke helper applications (eg. to setup test files). Use execApp() and TestApplication::execApp() to
  *   invoke the application to be tested itself.
- * - Currently only supported under UNIX.
  */
 int execHelperAppInSearchPath(
     const char *appName, const char *const *args, std::string &output, std::string &errors, bool suppressLogging, int timeout)
